#
# spec file for package tokodon
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.6.0
%define qt6_version 6.6.0

%bcond_without released
Name:           tokodon
Version:        24.12.0
Release:        1.1
Summary:        Mastodon client by KDE
License:        GPL-3.0-only
URL:            https://apps.kde.org/tokodon/
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF6ColorScheme) >= %{kf6_version}
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6DBusAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6Kirigami) >= %{kf6_version}
BuildRequires:  cmake(KF6KirigamiAddons) >= 0.11.40
BuildRequires:  cmake(KF6Notifications) >= %{kf6_version}
BuildRequires:  cmake(KF6Purpose) >= %{kf6_version}
BuildRequires:  cmake(KF6QQC2DesktopStyle) >= %{kf6_version}
BuildRequires:  cmake(KF6WindowSystem) >= %{kf6_version}
BuildRequires:  cmake(KUnifiedPush) >= 1.0.0
BuildRequires:  cmake(MpvQt)
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6Keychain)
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6QuickControls2) >= %{qt6_version}
BuildRequires:  cmake(Qt6Svg) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
BuildRequires:  cmake(Qt6WebSockets) >= %{qt6_version}
BuildRequires:  cmake(Qt6WebView) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  pkgconfig(mpv)
BuildRequires:  pkgconfig(openssl)
# It can only build on the same platforms as Qt Webengine
ExclusiveArch:  x86_64 %{x86_64} aarch64 riscv64
Requires:       kf6-kirigami-imports >= %{kf6_version}
Requires:       kf6-kitemmodels-imports >= %{kf6_version}
Requires:       kf6-sonnet-imports >= %{kf6_version}
Requires:       kirigami-addons6
Requires:       qt6-declarative-imports >= %{qt6_version}
Requires:       qt6-webview >= %{qt6_version}
Requires:       qt6-webview-imports >= %{qt6_version}

%description
Tokodon is a Mastodon client. It allows you to interact with the Fediverse
community.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%fdupes %{buildroot}

%find_lang tokodon tokodon.lang

%files
%license LICENSES/*
%doc README.md
%{_kf6_applicationsdir}/org.kde.tokodon.desktop
%{_kf6_appstreamdir}/org.kde.tokodon.appdata.xml
%{_kf6_bindir}/tokodon
%{_kf6_debugdir}/tokodon.categories
%{_kf6_iconsdir}/hicolor/scalable/apps/org.kde.tokodon.svg
%{_kf6_iconsdir}/hicolor/scalable/actions/*.svg
%{_kf6_notificationsdir}/tokodon.notifyrc
%{_kf6_plugindir}/kf6/purpose/tokodonplugin.so
%{_kf6_sharedir}/dbus-1/services/org.kde.tokodon.service

%files lang -f tokodon.lang

%changelog
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.0/
- Too many changes since 24.11.90, only listing bugfixes:
  * Word wrap the "Posted on" text (kde#496789)
  * Make sure to request custom emojis with authorization (kde#495585)
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.90
  * New feature release
- Too many changes since 24.11.80, only listing bugfixes:
  * Update read marker when streaming posts come in (kde#495159)
  * Don't show "Pinned posts" marker in notifications (kde#495110)
  * Fix the page stack not clearing properly when logging in (kde#496058)
  * Add back "Local" and "Global" timelines to the mobile sidebar (kde#496739)
  * Fix some PlaceholderMessages not having the correct width (kde#496762)
* Sat Nov 16 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.80
  * New feature release
- Too many changes since 24.08.3, only listing bugfixes:
  * Fix files not saving on Android (kde#496010)
  * Add missing Android icons (kde#496059)
  * Add profile field editing to the editor (kde#484293)
  * Support new notification events in v4.3.0, along with report types (kde#485168)
  * Only open the post when the content itself is tapped, not the sides (kde#485081)
  * Use the content font size setting in the composer (kde#489391)
  * Display media descriptions (or alt text) in a popup when clicked (kde#488532)
  * Fix the dialog for adding additional accounts looking odd (kde#491930)
  * Don't show quotes for hidden posts or with media attachments (kde#489833)
  * Fix the notification page breaking when someone posts a status (kde#490556)
  * Disable the scrollbar interactivity for timeline pages (kde#493431)
  * Add method for checking unread notifications, add it to the UI (kde#476947)
  * Stop pins from duplicating themselves (kde#494871)
  * Change bug reporting URL to the bug entry page. (kde#493429)
  * Make Edit on translatable (kde#493428)
  * Stop opening the sidebar on startup (kde#492030)
  * Do not reload accounts when initially setting the application proxy (kde#492383)
  * Fix creating new account on mobile (kde#491928)
  * Close modal sidebar when clicking on an entry (kde#491929)
* Tue Nov  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.3/
- Changes since 24.08.2:
  * Fix the "Add Account" button under Settings not working (kde#493485)
  * Fix the notification page breaking when someone posts a status (kde#490556)
  * Fix the "add list" and "edit list" pages not working
  * Handle deletion inside of actionRedraft itself, fix lots of signals
  * Fix undefined error in TimelinePage.title
  * Fix AttachmentMenu runtime warnings
  * Stop pins from duplicating themselves (kde#494871)
  * Add test for SocialGraphModel, fix a bug
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.2/
- Changes since 24.08.1:
  * Change bug reporting URL to the bug entry page. (kde#493429)
  * Make Edit on translatable (kde#493428)
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- Changes since 24.08.0:
  * Stop opening the sidebar on startup (kde#492030)
  * Fix registration not working
  * Fix erroneous if check that was using the wrong arguments list
  * Add KCrash
  * mention everyone in replies
  * Do not reload accounts when initially setting the application proxy (kde#492383)
  * Only emit reload accounts signal if they actually were
  * Fix creating new account on mobile (kde#491928)
  * flatpak: Update LuaJIT to a snapshot
  * Close modal sidebar when clicking on an entry (kde#491929)
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- Too many changes since 24.05.2, only listing bugfixes:
  * Only print out HTTP warnings for errors we don't explicitly handle (kde#486825)
  * Silently fail when 404'ing on featured tags (kde#484475)
  * Allow pasting bitmap images directly, like from the Internet (kde#488629)
  * Add an option to pop out the post composer by default (kde#489379)
  * Do not overwrite existing text in composer (kde#489781)
  * Let users be able to clear content warning (kde#488631)
  * Actually propagate the spoiler text to the composer when editing a post (kde#488631)
  * Specify that you're "saving" an edit in the composer (kde#488632)
  * Prevent notes field on profiles from stopping keyboard navigation (kde#488236)
  * Support PageUp/PageDown keys to quickly navigate the timeline (kde#487507)
  * Explain why some posts can't be boosted (kde#488172)
  * Fix wrong "%%1 boosted" label on certain posts (kde#485637)
  * Don't enforce the spellchecker even when it's disabled (kde#486465)
  * Fix the content font not actually affecting the post text (kde#481911)
  * Copy the spoiler text in replies (kde#486691)
  * Improve wording of the "Discard Draft" dialog (kde#484191)
* Tue Jul  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.2/
- Changes since 24.05.1:
  * Fix the private post notice messing with the post width in odd ways
  * Disable hidden post menu entries
  * Fix the loading indicator not showing up initially on the timeline
  * Let users be able to clear content warning (kde#488631)
  * Actually propagate the spoiler text to the composer when editing a post (kde#488631)
  * Prevent notes field on profiles from stopping keyboard navigation (kde#488236)
* Wed Jun 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.1/
- Changes since 24.05.0:
  * Support PageUp/PageDown keys to quickly navigate the timeline (kde#487507)
  * 🍒 Fix possible segfault after logout on timeline pages
  * Only clear page stack if authentication was successful
  * Don't allow continuing without inputting an authorization code
  * 🍒 Fix non-functional authorization link
  * Fix wrong "%%1 boosted" label on certain posts (kde#485637)
  * Revert "Re-enable Appium tests on the CI"
* Sun May 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.0/
- Changes since 24.04.80:
  * Don't enforce the spellchecker even when it's disabled (kde#486465)
  * Fix the content font not actually affecting the post text (kde#481911)
  * Fix multiple fullscreen images appearing on top of each other
  * Improve mentions in the composer, move content warning field
  * Copy the spoiler text in replies (kde#486691)
  * Fix pasting text content in the status composer
* Fri May  3 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.04.80
  * New feature release
- Too many changes since 24.02.2, only listing bugfixes:
  * Make QtWebView optional, overhaul auth (again) (kde#483938)
  * Resolve remote posts in the search box (kde#485080)
  * Allow popping out the status composer on desktop (kde#470048)
  * Remove minimum window size on mobile (kde#482844)
  * Refresh the thread if we reply to it (kde#480695)
  * PostContent: assorted bidirectionality fixes (kde#475043)
  * Add initial setup flow where required (kde#477927)
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- Changes since 24.02.1:
  * Resolve remote posts in the search box (kde#485080)
  * In the case that login fails, fall back to showing the network error
  * Comply with the flathub quality guidelines
  * Add branding color
  * Fix placeholder string in recent translation fix
  * Fix untranslatable string, improve format
  * Disable grouping follow notifications for now
* Wed Mar 27 2024 Julius Enriquez <win8linux@gmail.com>
- Add qt6-webview dep to fix login (boo#1222024)
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- Changes since 24.02.0:
  * Remove minimum window size on mobile (kde#482844)
  * Use since_id instead of min_id in grabbing push notifications
  * Post push notifications in reverse order
  * Reimplement an early exit when there's no accounts with no notifications
  * Add NotificationHandler::lastNotificationClosed signal
  * Create only one NotificationHandler and put it in AccountManager
  * flatpak: Switch to non-preview runtime
  * Fix keyboard navigatin in the Sidebar
  * Add margins to the video player controls
  * Don't allow opening a context menu for an image if it's hidden
  * Fix spacing on post info that has an application
  * Disable interactivity of the alt and other attachment chip
  * Hide embed action for private posts
  * Fix z order of the link indicator
  * Hide interaction buttons on most notifications except for mentions
  * Prevent crash when grouped notifications are used on initialization
  * Enable grouping notifications by default
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- Changes since 24.01.95:
  * Hide interaction buttons on most notifications except for mentions
  * Prevent crash when grouped notifications are used on initialization
  * Enable grouping notifications by default
  * Disable boosting private (followers-only) posts
  * Add 24.02 release note
  * Remove image attachment captions
  * Fix bottom margin on settings button in sidebar
  * Refresh the thread if we reply to it (kde#480695)
  * Hide actions on mobile that are already present in the bottom bar
  * TapHandler fixes to hopefully solve page switching woes
* Fri Feb  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.01.95
  * https://kde.org/announcements/megarelease/6/rc2/
* Fri Dec 15 2023 Christophe Marin <christophe@krop.fr>
- Require extra-cmake-modules at build time
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- Changes since 23.08.3:
  * Force the fullscreen image viewer focus so keybinds work
  * Protect against a notification missing a post (kde#475825)
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- Changes since 23.08.2:
  * Fix account switcher not working in certain sections (kde#475897)
  * snapcraft: fix package, gnome-keyring not gnome-keychain
  * snapcraft: Bundle gnome-keychain for libsecret. New content pack.
    Use kirigami-addons meta package.
  * Add CI template for building APKs on invent
  * snapcraft: Add missing qml module for purpose.
  * snapcraft: remove quote accidently placed at the end of LD_LIBRARY_PATH..
  * snapcraft: Set LD_LIBRARY_PATH at runtime to include libs in subdirs
    not found. Add missing qml module.
  * snapcraft: add missing libblas and add to LD search path. Add libsecret dep.
  * Remove _L1 from cherry-picking error
  * Fix some weird attachment issues if they don't exist locally
  * snapcraft: add missing dep libmpv.
  * snapcraft: initial import snapcraft files.
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- Changes since 23.08.1:
  * Protect against notifications that don't have a post associated (kde#475057)
  * Require kirigami-addons 0.11
  * Fix the follows page in notifications not working at all
  * Use the TextArea's implicitHeight when calculating composer height (kde#471519)
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- Changes since 23.08.0:
  * Add release note for the past two versions
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- Changes since 23.07.90:
  * Add fake identity so the timeline test works again
  * Use upload icons instead of download icons in the profile editor
  * You did implement account editing, uncomment the arrow
  * Use display name instead of the username in the timeline name
  * Stop Qt Quick from complaining because "there's no place to replace"
  * Improve Poll, by removing the invalid state and registering it properly
  * Stop UserInfo from reading the pageStack if nothing has been added to it
  * Fix AbstractAccount::apiUrl to strip slashes
  * Stop interactions with posts causing the entire delegate to reload
  * Improve default language selection when the preference is missing
  * Add support for more poll options, if Pleroma/Akkoma reports it
  * Handle Pleroma/Akkoma storing max post characters differently
  * Fix my dumb mistake of adding two of the same property
  * Set a maximum line count so link descriptions elide properly
  * Fix the instance name sometimes getting out of sync in switcher
  * Overhaul status composer attachment grid to match expected behavior
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- Changes since 23.07.80:
  * Fix spacing in LinkPreview
  * Show Link Preview only when Post Content is visible.
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Too many changes since 23.04.3, only listing bugfixes:
  * Open account links inside Tokodon (kde#472496)
  * Respect the filter action, so users can completely hide filtered posts (kde#471211)
  * Set the custom icon theme to the main icon theme, not the fallback (kde#467143)
  * Squash yet another duplicate accounts bug (kde#466440)
  * Better communique state of search progress (kde#467206)
  * Add a loading placeholder for searching (kde#467206)
  * When user hides media, automatically pause the video (kde#467214)
  * Fix -v arg not working when tokodon is already running (kde#467205)
  * Allow submitting posts by pressing CTRL+ENTER or CTRL+RETURN (kde#467164)
  * Make the composer text automatically focused (kde#467162)
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- No code change since 23.04.2
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- Changes since 23.04.1:
  * Fix obvious copy/paste mistakes
  * When going to separate app pages, clear the whole pageStack
  * Squash yet another duplicate accounts bug (kde#466440)
  * Fix reading invalid accounts from conf
* Wed May 24 2023 Christophe Marin <christophe@krop.fr>
- Require kirigami-addons
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- Changes since 23.04.0:
  * fix full screen image preview on NotificationPage
  * fix new post action on NotificationPage
  * Fix visible binding loop on TimelinePage
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Sat Mar 18 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Fri Feb 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.02.0:
  * https://carlschwan.eu/2023/02/17/tokodon-23.02.0-release/
  * Post composer revamp
  * The models for timelines has been completely refactored
  * The search field introduced during the last released got a
    nice visual refresh
  * It is now possible to configure the color scheme used by
    Tokodon independently from the Plasma color scheme
* Mon Jan  2 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.01.0
  * New timeline design
  * Searching post, accounts, tags is now possible
  * Hashtag Handling
  * Conversation View
  * Poll Support
  * Account Editor
  * Real-Time Timeline Update
* Tue Dec 20 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.11.2
  * New account switcher
  * Image previews are now contained inside the window
  * Improvements in loading media
  * Support for custom emojis
* Fri Nov 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Init tokodon
